.. Expyriment documentation master file, created by
   sphinx-quickstart on Fri Apr  5 15:08:26 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Expyriment |release| documentation
==================================
.. image:: expyriment_logo.png

*A Python library for cognitive and neuroscientific experiments*. :doc:`Read more
...<Overview>`

Table Of Contents
-----------------

.. toctree::
   :titlesonly:
   :maxdepth: 2

   Overview
   Getting started <GettingStarted>
   Advanced
   API reference <expyriment>
   Changelog
   Previous versions <PreviousVersions>
